#
# spec file for package python-tuf
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           python-tuf
Version:        6.0.0
Release:        1.1
Summary:        A secure updater framework for Python
License:        MIT
URL:            https://github.com/theupdateframework/python-tuf
Source:         https://github.com/theupdateframework/python-tuf/archive/v%{version}.tar.gz#/tuf-%{version}.tar.gz
BuildRequires:  %{python_module hatchling}
BuildRequires:  %{python_module pip}
BuildRequires:  python-rpm-macros
# SECTION test requirements
BuildRequires:  %{python_module urllib3 < 3}
BuildRequires:  %{python_module cryptography}
BuildRequires:  %{python_module ed25519}
BuildRequires:  %{python_module freezegun}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module securesystemslib >= 1.0}
# /SECTION
BuildRequires:  fdupes
Requires:       python-securesystemslib >= 1.0
Requires:       python-urllib3 < 3
BuildArch:      noarch
%python_subpackages

%description
The Update Framework (TUF) is a framework for secure content delivery
and updates. It protects against various types of supply chain attacks
and provides resilience to compromise.

%prep
%autosetup -p1 -n python-tuf-%{version}

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
pushd tests
%pytest
popd

%files %{python_files}
%doc README.md
%license LICENSE LICENSE-MIT
%{python_sitelib}/tuf
%{python_sitelib}/tuf-%{version}.dist-info

%changelog
* Wed Apr 16 2025 Steve Kowalik <steven.kowalik@suse.com>
- Update to 6.0:
  * ngclient: urllib3 is used as the HTTP library by default instead of
    requests.
  * ngclient: TLS certificate source was changed. Certificates now come from
    operating system certificate store instead of certifi.
  * ngclient: The updater can now initialize from embedded initial root
    metadata every time.
  * Test infrastructure has improved and should now be more usable externally.
- Remove duplicate BuildRequires on fdupes.
* Thu Oct 31 2024 Daniel Garcia <daniel.garcia@suse.com>
- Initial version (5.1.0)
